==> openshift-model-miscellaneous-5.10.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/FirmwareConfigBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class FirmwareConfigBuilder extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfigFluentImpl<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfig,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfigBuilder>{
  public FirmwareConfigBuilder() {
    this(false);
  }
  public FirmwareConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new FirmwareConfig(), validationEnabled);
  }
  public FirmwareConfigBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public FirmwareConfigBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new FirmwareConfig(), validationEnabled);
  }
  public FirmwareConfigBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfigFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfig instance) {
    this(fluent, instance, false);
  }
  public FirmwareConfigBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfigFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withSimultaneousMultithreadingEnabled(instance.getSimultaneousMultithreadingEnabled()); 
    fluent.withSriovEnabled(instance.getSriovEnabled()); 
    fluent.withVirtualizationEnabled(instance.getVirtualizationEnabled()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public FirmwareConfigBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfig instance) {
    this(instance,false);
  }
  public FirmwareConfigBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withSimultaneousMultithreadingEnabled(instance.getSimultaneousMultithreadingEnabled()); 
    this.withSriovEnabled(instance.getSriovEnabled()); 
    this.withVirtualizationEnabled(instance.getVirtualizationEnabled()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfig build() {
    FirmwareConfig buildable = new FirmwareConfig(fluent.getSimultaneousMultithreadingEnabled(),fluent.getSriovEnabled(),fluent.getVirtualizationEnabled());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FirmwareConfigBuilder that = (FirmwareConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-6.5.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/FirmwareConfigBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class FirmwareConfigBuilder extends FirmwareConfigFluentImpl<FirmwareConfigBuilder> implements VisitableBuilder<FirmwareConfig,FirmwareConfigBuilder>{
  public FirmwareConfigBuilder() {
    this(false);
  }
  public FirmwareConfigBuilder(Boolean validationEnabled) {
    this(new FirmwareConfig(), validationEnabled);
  }
  public FirmwareConfigBuilder(FirmwareConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public FirmwareConfigBuilder(FirmwareConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new FirmwareConfig(), validationEnabled);
  }
  public FirmwareConfigBuilder(FirmwareConfigFluent<?> fluent,FirmwareConfig instance) {
    this(fluent, instance, false);
  }
  public FirmwareConfigBuilder(FirmwareConfigFluent<?> fluent,FirmwareConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withSimultaneousMultithreadingEnabled(instance.getSimultaneousMultithreadingEnabled()); 
    fluent.withSriovEnabled(instance.getSriovEnabled()); 
    fluent.withVirtualizationEnabled(instance.getVirtualizationEnabled()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public FirmwareConfigBuilder(FirmwareConfig instance) {
    this(instance,false);
  }
  public FirmwareConfigBuilder(FirmwareConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withSimultaneousMultithreadingEnabled(instance.getSimultaneousMultithreadingEnabled()); 
    this.withSriovEnabled(instance.getSriovEnabled()); 
    this.withVirtualizationEnabled(instance.getVirtualizationEnabled()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  FirmwareConfigFluent<?> fluent;
  Boolean validationEnabled;
  public FirmwareConfig build() {
    FirmwareConfig buildable = new FirmwareConfig(fluent.getSimultaneousMultithreadingEnabled(),fluent.getSriovEnabled(),fluent.getVirtualizationEnabled());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
